---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Give exact command you ran. When you run ASTRAL, make sure you keep the standard error (e.g., by adding ` 2>astral.log` to the end of your command). 

**Log file**
Send us the log file (standard error of ASTRAL)

** Version 

**Additional context**
Add any other context about the problem here.
